@@ -211,6 +211,7 @@ Rg_to_F2xq(GEN x, GEN T)
 ulong
 F2x_eval(GEN P, ulong x)
 {
+  if (lgpol(P)==0) return 0;
   if (odd(x))
   {
     long i, lP = lg(P);
@@ -631,7 +632,9 @@ F2x_shiftneg(GEN y, ulong d)
 {
   long db, dl=dvmdsBIL(d, &db);
   long i, ly = lg(y), lx = ly-dl;
-  GEN x = cgetg(lx, t_VECSMALL);
+  GEN x;
+  if (lx <= 2) return zero_F2x(y[1]);
+  x = cgetg(lx, t_VECSMALL);
   x[1] = y[1];
   if (db)
   {
