@@ -4,7 +4,8 @@ This file is part of the PARI/GP package.
 
 PARI/GP is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
-Foundation. It is distributed in the hope that it will be useful, but WITHOUT
+Foundation; either version 2 of the License, or (at your option) any later
+version. It is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
@@ -142,7 +143,7 @@ Flx_addifsmooth3(pari_sp *av, struct Flxq_log_rel *r, GEN h, long u, long v, lon
     if (DEBUGLEVEL && (r->nbrel&511UL)==0)
       err_printf("%ld%% ",r->nbrel*100/r->nbexp);
     *av = avma;
-  } else avma = *av;
+  } else set_avma(*av);
   return r->nbrel==r->nb || r->nbrel==r->nbmax;
 }
 
@@ -304,7 +305,7 @@ smooth_best(long p, long n, long *pt_r, long *pt_nb)
       {
         rels = itou_or_0(addui(rels, gceil(gmul(gdivgs(sqri(Nmax),6),pr))));
         if (!rels) rels = ULONG_MAX;
-        avma = av2;
+        set_avma(av2);
         continue;
       }
       c = gdivgs(addii(powuu(p,2*d),sqri(N)),6);
@@ -352,7 +353,7 @@ check_kernel(long r, GEN M, long nbi, long nbrow, GEN T, ulong p, GEN m)
     pari_sp av = avma;
     long t = signe(k) && Flx_equal(Flxq_pow_table(tab, k, T, p),
                                    Flxq_pow(cindex_Flx(i,r,p,T[1]), idx, T, p));
-    avma = av;
+    set_avma(av);
     if (!t)
       gel(K,i) = cgetineg(lm);
     else
@@ -401,7 +402,7 @@ Flxq_log_use_index_cubic(GEN m, GEN T0, ulong p)
   GEN cost = smooth_best(p, n, &r, &nb);
   GEN cost_rho = sqrti(shifti(m,2));
   int use = (cost && gcmp(cost,cost_rho)<0);
-  avma = av;
+  set_avma(av);
   return use;
 }
 
@@ -416,7 +417,7 @@ Flxq_log_index_cubic(GEN a0, GEN b0, GEN m, GEN T0, ulong p)
   pari_timer ti;
   GEN cost = smooth_best(p, n, &r, &nb);
   GEN cost_rho = sqrti(shifti(m,2));
-  if (!cost || gcmp(cost,cost_rho)>=0) { avma = av; return NULL; }
+  if (!cost || gcmp(cost,cost_rho)>=0) return gc_NULL(av);
   nbi = itos(ffsumnbirred(stoi(p), r));
   if (DEBUGLEVEL)
   {
@@ -494,7 +495,7 @@ Flxq_log_Coppersmith_worker(GEN u, long i, GEN V, GEN R)
     Flx_cnext(v, p);
     Flx_renormalize_inplace(v, dT+2);
     lv = Flx_lead(v);
-    avma = av;
+    set_avma(av);
     if (lu != 1 && lv != 1) continue;
     if (degpol(Flx_gcd(u, v, p))!=0) continue;
     if (lu==1)
@@ -556,7 +557,7 @@ Flxq_log_Coppersmith(long nbrel, long r, GEN T, ulong p)
       }
       av = avma;
     }
-    else avma = av;
+    else set_avma(av);
     if (rel>nbrel) stop = 1;
     i++;
   }
@@ -614,7 +615,7 @@ Flxq_log_Coppersmith_d(GEN W, GEN g, long r, GEN T, ulong p, GEN mo)
   {
     GEN p0,q,qh,a,b;
     ulong el = i;
-    avma = av2;
+    set_avma(av2);
     q = pol0_Flx(T[1]);
     for (j=1; j<=k; j++)
     {
@@ -639,7 +640,7 @@ Flxq_log_Coppersmith_d(GEN W, GEN g, long r, GEN T, ulong p, GEN mo)
       GEN R  = famatsmall_reduce(mkmat2(FG, E));
       GEN l  = Flxq_log_from_rel(W, R, r, T, p, mo);
       if (!l) continue;
-      l = Fp_div(l,utoi(p),mo);
+      l = Fp_divu(l,p,mo);
       if (dg <= r)
       {
         long idx = Flx_cindex(g, p);
@@ -649,7 +650,7 @@ Flxq_log_Coppersmith_d(GEN W, GEN g, long r, GEN T, ulong p, GEN mo)
       return gerepileuptoint(av, l);
     }
   }
-  avma = av;
+  set_avma(av);
   return NULL;
 }
 
