@@ -108,7 +108,7 @@ bernset(GEN *y, long m, long n)
     affrr(divrunu(mulrr(v,u), k-1), v);
     for (j = r; j >= 3; j -= 2) affii(muliu2(gel(t,j), j), gel(t,j));
     set_avma(av2); k -= 2;
-    if ((k & 0xf) == 0)
+    if (((N - k) & 0x7f) == 0x7e)
     { /* reduce precision if possible */
       long p2 = p, prec2 = prec, r2;
       p = bernbitprec(k);
@@ -173,7 +173,10 @@ constbern(long nb)
     t = Flx_Laplace(Flxn_inv(t, n, p), p);
     for (i = 1; i <= nb; i++)
       if (Rg_to_Fl(bernfrac(2*i), p) != uel(t,2*i+2))
+      {
+        gunclone(bernzone); bernzone = NULL;
         pari_err_BUG(stack_sprintf("B_{2*%ld}", i));
+      }
     set_avma(av);
   }
 }
