@@ -332,16 +332,16 @@ static int
 is_monomial_test(GEN x, long v, int(*test)(GEN))
 {
   long d, i, l;
-  if (!signe(x)) return (typ(x) == t_SER && v <= 0);
   if (v > 0) return 0;
-  l = lg(x); d = 2-v;
-  if (l <= d) return 0;
-  /* 2 <= d < l */
-  if (!test(gel(x,d))) return 0;
-  for (i = 2; i < d; i++)
-    if (!gequal0(gel(x,i))) return 0;
-  for (i = d+1; i < l; i++)
-    if (!gequal0(gel(x,i))) return 0;
+  l = lg(x);
+  if (!signe(x))
+  {
+    if (typ(x) == t_SER) return v + l - 2 <= 0;
+    return l > 2 && test(gel(x,2)); /* e.g. O(2^-1)*x^0 */
+  }
+  d = 2-v; if (l <= d || !test(gel(x,d))) return 0;
+  for (i = 2; i < l; i++) /* 2 <= d < l */
+    if (i != d && !gequal0(gel(x,i))) return 0;
   return 1;
 }
 static int
@@ -387,7 +387,7 @@ gequal1(GEN x)
     case t_INTMOD:
       return is_pm1(gel(x,2)) || is_pm1(gel(x,1));
     case t_POLMOD:
-      return gequal1(gel(x,2)) || gequal1(gel(x,1));
+      return !degpol(gel(x,1)) || gequal1(gel(x,2));
 
     case t_FFELT:
       return FF_equal1(x);
@@ -399,7 +399,8 @@ gequal1(GEN x)
       return gequal1(gel(x,1)) && gequal0(gel(x,2));
 
     case t_PADIC:
-      return !valp(x) && gequal1(gel(x,4));
+      if (!signe(gel(x,4))) return valp(x) <= 0;
+      return valp(x) == 0 && gequal1(gel(x,4));
 
     case t_QUAD:
       return gequal1(gel(x,2)) && gequal0(gel(x,3));
@@ -419,7 +420,7 @@ int
 gequalm1(GEN x)
 {
   pari_sp av;
-  GEN p1;
+  GEN t;
 
   switch(typ(x))
   {
@@ -448,11 +449,11 @@ gequalm1(GEN x)
       return gequalm1(gel(x,2)) && gequal0(gel(x,3));
 
     case t_PADIC:
-      av = avma; return gc_bool(av, equalii(addui(1,gel(x,4)), gel(x,3)));
+      t = gel(x,4); if (!signe(t)) return valp(x) <= 0;
+      av = avma; return gc_bool(av, !valp(x) && equalii(addui(1,t), gel(x,3)));
 
     case t_POLMOD:
-      av = avma; p1 = gaddgs(gel(x,2), 1);
-      return gc_bool(av, gequal0(p1) || gequal(p1,gel(x,1)));
+      return !degpol(gel(x,1)) || gequalm1(gel(x,2));
 
     case t_POL: return is_monomial_test(x, 0, &gequalm1);
     case t_SER: return is_monomial_test(x, valp(x), &gequalm1);
