@@ -26,6 +26,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
  * the License, or (at your option) any later version.                 *
  ***********************************************************************/
 
+#include "paricfg.h"
+#ifdef HAS_SSE2
+#include <emmintrin.h>
+#endif
+
 #include "pari.h"
 #include "paripriv.h"
 
@@ -57,9 +62,8 @@ typedef struct {double low; double up;} ratpoints_interval;
 
 /* Some Macros for working with SSE registers */
 #ifdef HAS_SSE2
-#include <emmintrin.h>
 
-#define AND(a,b) ((ratpoints_bit_array)__builtin_ia32_andps((__v4sf)(a), (__v4sf)(b)))
+#define AND(a,b) ((a)&(b))
 #define EXT0(a) ((ulong)__builtin_ia32_vec_ext_v2di((__v2di)(a), 0))
 #define EXT1(a) ((ulong)__builtin_ia32_vec_ext_v2di((__v2di)(a), 1))
 #define TEST(a) (EXT0(a) || EXT1(a))
@@ -71,7 +75,6 @@ typedef __v2di ratpoints_bit_array;
 #define RBA_LENGTH (128)
 #define RBA_SHIFT (7)
 #define RBA_ALIGN  (sizeof(ratpoints_bit_array))
-#define RBA_MASK (~(-(1UL<<RBA_SHIFT)))
 
 #else
 /* Use ulong for the bit arrays */
@@ -84,7 +87,6 @@ typedef ulong ratpoints_bit_array;
 #define RBA_LENGTH BITS_IN_LONG
 #define RBA_SHIFT TWOPOTBITS_IN_LONG
 #define RBA_ALIGN  (sizeof(long))
-#define RBA_MASK LONG_MASK
 
 #endif
 
@@ -1597,6 +1599,31 @@ process(long a, long b, GEN y, void *info0, int *quit)
   return 1;
 }
 
+static int
+args_h(ratpoints_args *args, GEN D)
+{
+  long H, h, l = 1;
+  GEN L;
+  switch(typ(D))
+  {
+    case t_INT: if (signe(D) <= 0) return 0;
+      H = h = itos(D); break;
+    case t_VEC: if (lg(D) != 3) return 0;
+      H = gtos(gel(D,1));
+      L = gel(D,2);
+      if (typ(L)==t_INT) { h = itos(L); break; }
+      if (typ(L)==t_VEC && lg(L)==3)
+      {
+        l = gtos(gel(L,1));
+        h = gtos(gel(L,2)); break;
+      }
+    default: return 0;
+  }
+  args->height = H;
+  args->b_low  = l;
+  args->b_high = h; return 1;
+}
+
 static GEN
 ZX_hyperellratpoints(GEN P, GEN h, long flag)
 {
@@ -1607,26 +1634,11 @@ ZX_hyperellratpoints(GEN P, GEN h, long flag)
 
   if (!ZX_is_squarefree(P))
     pari_err_DOMAIN("hyperellratpoints","issquarefree(pol)","=",gen_0, P);
-  if (typ(h)==t_INT && signe(h)>0)
+  if (!args_h(&args, h))
   {
-    long H = itos(h);
-    args.height        = H;
-    args.b_low         = 1;
-    args.b_high        = H;
-  } else if (typ(h)==t_VEC && lg(h)==3)
-  {
-    args.height        = gtos(gel(h,1));
-    if (typ(gel(h,2))==t_INT)
-    {
-      args.b_low         = 1;
-      args.b_high        = itos(gel(h,2));
-    } else if (typ(gel(h,2))==t_VEC && lg(gel(h,2))==3)
-    {
-      args.b_low         = gtos(gmael(h,2,1));
-      args.b_high        = gtos(gmael(h,2,2));
-    } else pari_err_TYPE("hyperellratpoints",h);
-  } else pari_err_TYPE("hyperellratpoints",h);
-
+    pari_err_TYPE("hyperellratpoints", h);
+    return NULL;/*LCOV_EXCL_LINE*/
+  }
   find_points_init(&args, RATPOINTS_DEFAULT_BIT_PRIMES);
 
   args.cof           = shallowcopy(P);
